@@ -20,7 +20,7 @@ logger = None
 class AppServer(Config):
     # deprecated = password, dh_param_bits
     bool_options = {'debug', 'log_debug', 'auto_start_servers',
-        'get_public_ip', 'inline_certs', 'ssl'}
+        'get_public_ip', 'inline_certs', 'ssl', 'static_cache'}
     int_options = {'port', 'session_timeout', 'key_bits', 'dh_param_bits'}
     path_options = {'log_path', 'db_path', 'www_path', 'data_path',
         'server_cert_path', 'server_key_path'}
@@ -30,6 +30,9 @@ class AppServer(Config):
         'get_public_ip': True,
         'inline_certs': True,
         'ssl': True,
+        'static_cache': True,
+        'bind_addr': DEFAULT_BIND_ADDR,
+        'port': DEFAULT_PORT,
         'session_timeout': DEFAULT_SESSION_TIMEOUT,
         'key_bits': DEFAULT_KEY_BITS,
         'dh_param_bits': DEFAULT_DH_PARAM_BITS,
@@ -38,12 +41,14 @@ class AppServer(Config):
         'data_path': DEFAULT_DATA_PATH,
         'public_ip_server': DEFAULT_PUBLIC_IP_SERVER,
     }
+    read_env = True
 
     def __init__(self):
         Config.__init__(self)
         self.app = None
         self.interrupt = False
         self.public_ip = None
+        self.conf_path = DEFAULT_CONF_PATH
 
     def __getattr__(self, name):
         if name == 'web_protocol':
@@ -149,18 +154,6 @@ class AppServer(Config):
     def _setup_handlers(self):
         import handlers
 
-    def _setup_static_handler(self):
-        from werkzeug import SharedDataMiddleware
-
-        self.app.wsgi_app = SharedDataMiddleware(self.app.wsgi_app, {
-            '/': os.path.normpath(self.www_path),
-        }, cache=False)
-
-        @self.app.route('/', methods=['GET'])
-        def index_get():
-            with open(os.path.join(self.www_path, 'index.html'), 'r') as fd:
-                return fd.read()
-
     def _get_version_int(self, version):
         return int(''.join([x.zfill(2) for x in version.split('.')]))
 
@@ -247,7 +240,6 @@ class AppServer(Config):
         self._upgrade_db()
         self._setup_db()
         self._setup_handlers()
-        self._setup_static_handler()
         self._upgrade_data()
         self._fill_cache()
 
