@@ -14,6 +14,8 @@ RESTART = 'restart'
 NAME_SAFE_CHARS = {'-', '=', '_', '@', '.', ':', '/'}
 
 KEY_LINK_TIMEOUT = 86400
+DEFAULT_BIND_ADDR = '0.0.0.0'
+DEFAULT_PORT = 9700
 DEFAULT_PRIMARY_INTERFACE = 'eth0'
 DEFAULT_SESSION_TIMEOUT = 86400
 DEFAULT_USERNAME = 'admin'
@@ -28,9 +30,11 @@ DEFAULT_KEY_BITS = 4096
 DEFAULT_DH_PARAM_BITS = 1536
 DEFAULT_OTP_SECRET_LEN = 16
 DEFAULT_PUBLIC_IP_SERVER = 'http://ip.pritunl.com/json'
+ENV_PREFIX = APP_NAME
 LOG_LIMIT = 100
 EVENT_TTL = 60
 RATE_LIMIT_SLEEP = 0.5
+SERVER_STATUS_RATE = 10
 SHORT_URL_LEN = 5
 SHORT_URL_CHARS = (string.ascii_lowercase + string.ascii_uppercase +
     string.digits).replace('l', '').replace('I', '').replace('O', '').replace(
@@ -41,6 +45,7 @@ HTTP_COM_REQUEST_TIMEOUT = 60
 SERVER_REQUEST_QUEUE_SIZE = 512
 USER_PAGE_COUNT = 10
 NODE_SERVER_VER = 1
+STATIC_CACHE_TIME = 43200
 IP_REGEX = r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}'
 
 INFO = 'info'
@@ -73,9 +78,10 @@ SERVER_USER_PREFIX = 'server_'
 SERVER_CERT_NAME = 'server.crt'
 SERVER_KEY_NAME = 'server.key'
 AUTH_LOG_NAME = 'auth.log'
+KEY_INDEX_NAME = 'key_index.html'
 CONF_TEMP_EXT = '.tmp'
-SERVER_NAME = 'server'
-NODE_SERVER_NAME = 'node_server'
+SERVER = 'server'
+NODE_SERVER = 'node_server'
 
 CA_CERT_ID = 'ca'
 CERT_CA = 'ca'
@@ -88,6 +94,7 @@ LOG_UPDATED = 'log_updated'
 SERVERS_UPDATED = 'servers_updated'
 SERVER_ORGS_UPDATED = 'server_organizations_updated'
 SERVER_OUTPUT_UPDATED = 'server_output_updated'
+SERVER_BANDWIDTH_UPDATED = 'server_bandwidth_updated'
 
 CERT_CONF = """[ default ]
 ca = %s
@@ -247,7 +254,7 @@ server %s
 ifconfig-pool-persist %s
 %s
 max-clients 1024
-keepalive 4 10
+keepalive 5 20
 persist-tun
 status %s 1
 status-version 2
@@ -266,7 +273,7 @@ server %s
 ifconfig-pool-persist %s
 %s
 max-clients 1024
-keepalive 4 10
+keepalive 5 20
 persist-tun
 status %s 1
 status-version 2
