@@ -1,6 +1,7 @@
 from pritunl.constants import *
 from pritunl.exceptions import *
 from pritunl.organization import Organization
+from pritunl.static_file import StaticFile
 import pritunl.utils as utils
 from pritunl.cache import cache_db
 from pritunl import app_server
@@ -70,6 +71,7 @@ def user_key_link_get(org_id, user_id):
             cache_db.dict_set(_get_conf_key(conf_id), 'server_id', server.id)
 
             conf_urls.append({
+                'id': conf_id,
                 'server_name': server.name,
                 'url': '/key/%s.ovpn' % conf_id,
             })
@@ -116,8 +118,8 @@ def user_linked_key_page_get(view_id):
     org = Organization.get_org(id=org_id)
     user = org.get_user(user_id)
 
-    key_page = open(os.path.join(app_server.www_path,
-        'key_index.html'), 'r').read()
+    key_page = StaticFile(os.path.join(
+        app_server.www_path, KEY_INDEX_NAME), cache=False).data
     key_page = key_page.replace('<%= user_name %>', '%s - %s' % (
         org.name, user.name))
     key_page = key_page.replace('<%= user_key_url %>', '/key/%s.tar' % (
@@ -132,6 +134,8 @@ def user_linked_key_page_get(view_id):
         key_page = key_page.replace('<%= user_otp_key %>', '')
         key_page = key_page.replace('<%= user_otp_url %>', '')
 
+    key_page = key_page.replace('<%= view_id %>', view_id)
+
     conf_links = ''
     for conf_url in conf_urls:
         conf_links += '<a class="sm" title="Download Mobile Key" ' + \
@@ -141,6 +145,18 @@ def user_linked_key_page_get(view_id):
 
     return key_page
 
+@app_server.app.route('/k/<view_id>', methods=['DELETE'])
+def user_linked_key_page_delete_get(view_id):
+    key_id = cache_db.dict_get(_get_view_key(view_id), 'key_id')
+    if key_id:
+        cache_db.remove(_get_key_key(key_id))
+    conf_urls = cache_db.dict_get(_get_view_key(view_id), 'conf_urls')
+    if conf_urls:
+        for conf_url in json.loads(conf_urls):
+            cache_db.remove(_get_conf_key(conf_url['id']))
+    cache_db.remove(_get_view_key(view_id))
+    return utils.jsonify({})
+
 @app_server.app.route('/key/<conf_id>.ovpn', methods=['GET'])
 def user_linked_key_conf_get(conf_id):
     org_id = cache_db.dict_get(_get_conf_key(conf_id), 'org_id')
