@@ -48,21 +48,20 @@ def _dns_server_invalid():
     }, 400)
 
 @app_server.app.route('/server', methods=['GET'])
+@app_server.app.route('/server/<server_id>', methods=['GET'])
 @app_server.auth
-def server_get():
-    servers = []
-    servers_dict = {}
-    servers_sort = []
+def server_get(server_id=None):
+    if server_id:
+        return utils.jsonify(Server.get_server(server_id).dict())
+    else:
+        servers = []
+        servers_dict = {}
+        servers_sort = []
 
-    for server in Server.iter_servers():
-        name_id = '%s_%s' % (server.name, server.id)
-        servers_sort.append(name_id)
-        servers_dict[name_id] = server.dict()
+        for server in Server.iter_servers():
+            servers.append(server.dict())
 
-    for name_id in sorted(servers_sort):
-        servers.append(servers_dict[name_id])
-
-    return utils.jsonify(servers)
+        return utils.jsonify(servers)
 
 @app_server.app.route('/server', methods=['POST'])
 @app_server.app.route('/server/<server_id>', methods=['PUT'])
@@ -84,12 +83,12 @@ def server_put_post(server_id=None):
         name_def = True
         name = utils.filter_str(flask.request.json['name'])
 
-    type = SERVER_NAME
+    type = SERVER
     type_def = False
     if 'type' in flask.request.json:
         type_def = True
-        if flask.request.json['type'] == NODE_SERVER_NAME:
-            type = NODE_SERVER_NAME
+        if flask.request.json['type'] == NODE_SERVER:
+            type = NODE_SERVER
 
     network = None
     network_def = False
@@ -360,7 +359,7 @@ def server_put_post(server_id=None):
             }, 400)
 
     if not server_id:
-        if type == NODE_SERVER_NAME:
+        if type == NODE_SERVER:
             server = NodeServer(
                 name=name,
                 network=network,
@@ -424,7 +423,7 @@ def server_put_post(server_id=None):
             server.lzo_compression = lzo_compression
         if debug_def:
             server.debug = debug
-        if server.type == NODE_SERVER_NAME:
+        if server.type == NODE_SERVER:
             if node_host_def:
                 server.node_host = node_host
             if node_port_def:
@@ -528,6 +527,14 @@ def server_output_delete(server_id):
     server.clear_output()
     return utils.jsonify({})
 
+@app_server.app.route('/server/<server_id>/bandwidth', methods=['GET'])
+@app_server.app.route('/server/<server_id>/bandwidth/<period>',
+    methods=['GET'])
+@app_server.auth
+def server_bandwidth_get(server_id, period=None):
+    server = Server.get_server(id=server_id)
+    return utils.jsonify(server.get_bandwidth(period=period))
+
 @app_server.app.route('/server/<server_id>/tls_verify', methods=['POST'])
 @app_server.local_only
 def server_tls_verify_post(server_id):
