@@ -22,7 +22,7 @@ class NodeServer(Server):
     default_options = dict(Server.default_options.items() + {
         'node_port': 9800,
     }.items())
-    type = NODE_SERVER_NAME
+    type = NODE_SERVER
 
     def dict(self):
         server_dict = Server.dict(self)
@@ -35,7 +35,7 @@ class NodeServer(Server):
 
     def _initialize(self):
         Server._initialize(self)
-        with open(os.path.join(self.path, NODE_SERVER_NAME), 'w'):
+        with open(os.path.join(self.path, NODE_SERVER), 'w'):
             pass
 
     def _request(self, method, endpoint='', timeout=HTTP_REQUEST_TIMEOUT,
@@ -74,6 +74,9 @@ class NodeServer(Server):
                         timeout=HTTP_COM_REQUEST_TIMEOUT, json_data=responses)
                     if response.status_code == 200:
                         pass
+                    elif response.status_code == 404:
+                        trigger_event = True
+                        break
                     elif response.status_code == 410:
                         break
                     else:
@@ -173,14 +176,6 @@ class NodeServer(Server):
             return
         return
 
-    def update_clients(self, clients):
-        client_count = len(self.clients)
-        self.clients = clients
-        if self.status and client_count != len(clients):
-            for org in self.iter_orgs():
-                Event(type=USERS_UPDATED, resource_id=org.id)
-            Event(type=SERVERS_UPDATED)
-
     def _generate_ovpn_conf(self):
         if not self.org_count:
             raise ServerMissingOrg('Ovpn conf cannot be generated without ' + \
