@@ -5,11 +5,12 @@ from config import Config
 from organization import Organization
 from event import Event
 from log_entry import LogEntry
-from cache import cache_db
+from cache import cache_db, persist_db
 import uuid
 import os
 import signal
 import time
+import datetime
 import subprocess
 import threading
 import logging
@@ -34,7 +35,6 @@ class Server(Config):
     def __init__(self, id=None, **kwargs):
         Config.__init__(self)
         self._cur_event = None
-        self._cur_client_count = 0
         self._last_event = 0
         self._rebuild_dh_params = False
 
@@ -152,15 +152,25 @@ class Server(Config):
         os.makedirs(os.path.join(self.path, TEMP_DIR))
         try:
             self._generate_dh_param()
+            cache_db.set_add('servers', '%s_%s' % (self.id, self.type))
             self.commit()
             LogEntry(message='Created new server "%s".' % self.name)
         except:
             logger.exception('Failed to create server. %r' % {
                 'server_id': self.id,
             })
+            self.clear_cache()
             utils.rmtree(self.path)
             raise
 
+    def clear_cache(self):
+        cache_db.set_remove('servers', '%s_%s' % (self.id, self.type))
+        cache_db.list_remove('servers_sorted', '%s_%s' % (self.id, self.type))
+        cache_db.remove(self.get_cache_key('clients'))
+        for period in ('1m', '5m', '30m', '2h', '1d'):
+            persist_db.remove(self.get_cache_key('bandwidth-%s' % period))
+        Config.clear_cache(self)
+
     def _event_delay(self, type, resource_id=None):
         # Min event every 1s max event every 0.2s
         event_time = time.time()
@@ -183,6 +193,7 @@ class Server(Config):
         logger.debug('Removing server. %r' % {
             'server_id': self.id,
         })
+        self.clear_cache()
         name = self.name
 
         if self.status:
@@ -197,6 +208,7 @@ class Server(Config):
         if self._rebuild_dh_params:
             self._generate_dh_param()
         Config.commit(self)
+        self.sort_servers_cache()
         Event(type=SERVERS_UPDATED)
 
     def _create_primary_user(self):
@@ -595,13 +607,13 @@ class Server(Config):
         i = 0
         cur_client_count = 0
         while not self._interrupt:
-            # Check interrupt every 0.1s check client count every 1s
-            if i == 9:
+            time.sleep(0.1)
+            # Check interrupt every 0.1s check client count every 5s
+            if i == SERVER_STATUS_RATE * 5:
                 i = 0
-                self.update_clients()
+                self._read_clients()
             else:
                 i += 1
-            time.sleep(0.1)
         self._clear_iptables_rules()
 
     def _run_thread(self):
@@ -730,26 +742,17 @@ class Server(Config):
         })
 
         stopped = False
-        self.publish('stop')
-        for message in cache_db.subscribe(self.get_cache_key(), 2):
+        self.publish('force_stop')
+        for message in cache_db.subscribe(self.get_cache_key(),
+                SUB_RESPONSE_TIMEOUT):
             if message == 'stopped':
                 stopped = True
                 break
-
         if not stopped:
-            stopped = False
-            self.publish('force_stop')
-            for message in cache_db.subscribe(self.get_cache_key(),
-                    SUB_RESPONSE_TIMEOUT):
-                if message == 'stopped':
-                    stopped = True
-                    break
-
-            if not stopped:
-                raise ServerStopError('Server thread failed to return ' + \
-                    'stop event', {
-                        'server_id': self.id,
-                    })
+            raise ServerStopError('Server thread failed to return ' + \
+                'stop event', {
+                    'server_id': self.id,
+                })
 
         if not silent:
             Event(type=SERVERS_UPDATED)
@@ -778,11 +781,243 @@ class Server(Config):
         cache_db.list_rpush(self.get_cache_key('output'), output.rstrip('\n'))
         self._event_delay(type=SERVER_OUTPUT_UPDATED, resource_id=self.id)
 
-    def update_clients(self):
-        if not self.status:
-            return {}
-        clients = {}
+    def get_bandwidth(self, period=None):
+        data = {}
+        date = datetime.datetime.utcnow()
+        date -= datetime.timedelta(microseconds=date.microsecond,
+            seconds=date.second)
+        periods = (period,) if period else ('1m', '5m', '30m', '2h', '1d')
 
+        for period in periods:
+            if period == '1m':
+                date_end = date
+                date_cur = date_end - datetime.timedelta(hours=6)
+                date_step = datetime.timedelta(minutes=1)
+            elif period == '5m':
+                date_end = date - datetime.timedelta(minutes=date.minute % 5)
+                date_cur = date_end - datetime.timedelta(days=1)
+                date_step = datetime.timedelta(minutes=5)
+            elif period == '30m':
+                date_end = date - datetime.timedelta(minutes=date.minute % 30)
+                date_cur = date_end - datetime.timedelta(days=7)
+                date_step = datetime.timedelta(minutes=30)
+            elif period == '2h':
+                date_end = date - datetime.timedelta(minutes=date.minute,
+                    hours=date.hour % 2)
+                date_cur = date_end - datetime.timedelta(days=30)
+                date_step = datetime.timedelta(hours=2)
+            elif period == '1d':
+                date_end = date - datetime.timedelta(minutes=date.minute,
+                    hours=date.hour)
+                date_cur = date_end - datetime.timedelta(days=365)
+                date_step = datetime.timedelta(days=1)
+
+            data_p = {
+                'received': [],
+                'received_total': 0,
+                'sent': [],
+                'sent_total': 0,
+            }
+            data[period] = data_p
+            cache_key = self.get_cache_key('bandwidth-%s' % period)
+
+            while date_cur < date_end:
+                date_cur += date_step
+
+                timestamp = int(date_cur.strftime('%s'))
+                bandwidth = persist_db.dict_get(cache_key, str(timestamp))
+                if bandwidth:
+                    bandwidth = bandwidth.split(',')
+                    bytes_recv = int(bandwidth[0])
+                    bytes_sent = int(bandwidth[1])
+                else:
+                    bytes_recv = 0
+                    bytes_sent = 0
+
+                data_p['received'].append((timestamp, bytes_recv))
+                data_p['received_total'] += bytes_recv
+                data_p['sent'].append((timestamp, bytes_sent))
+                data_p['sent_total'] += bytes_sent
+
+        if len(periods) == 1:
+            return data[periods[0]]
+        else:
+            return data
+
+    def get_bandwidth_random(self, period=None):
+        # Generate random bandwidth data for demo and write to file
+        import json
+        import random
+        data = {}
+        date = datetime.datetime.utcnow()
+        date -= datetime.timedelta(microseconds=date.microsecond,
+            seconds=date.second)
+        periods = (period,) if period else ('1m', '5m', '30m', '2h', '1d')
+
+        for period in periods:
+            if period == '1m':
+                date_end = date
+                date_cur = date_end - datetime.timedelta(hours=6)
+                date_step = datetime.timedelta(minutes=1)
+                bytes_recv = 700000
+                bytes_sent = 700000
+                bandwidth_rand = lambda x: random.randint(
+                    max(x - 50000, 0), max(x + 50000, 0))
+            elif period == '5m':
+                date_end = date - datetime.timedelta(minutes=date.minute % 5)
+                date_cur = date_end - datetime.timedelta(days=1)
+                date_step = datetime.timedelta(minutes=5)
+                bytes_recv = 3500000
+                bytes_sent = 3500000
+                bandwidth_rand = lambda x: random.randint(
+                    max(x - 250000, 0), max(x + 250000, 0))
+            elif period == '30m':
+                date_end = date - datetime.timedelta(minutes=date.minute % 30)
+                date_cur = date_end - datetime.timedelta(days=7)
+                date_step = datetime.timedelta(minutes=30)
+                bytes_recv = 21000000
+                bytes_sent = 21000000
+                bandwidth_rand = lambda x: random.randint(
+                    max(x - 2000000, 0), max(x + 2000000, 0))
+            elif period == '2h':
+                date_end = date - datetime.timedelta(minutes=date.minute,
+                    hours=date.hour % 2)
+                date_cur = date_end - datetime.timedelta(days=30)
+                date_step = datetime.timedelta(hours=2)
+                bytes_recv = 84000000
+                bytes_sent = 84000000
+                bandwidth_rand = lambda x: random.randint(
+                    max(x - 2000000, 0), max(x + 2000000, 0))
+            elif period == '1d':
+                date_end = date - datetime.timedelta(minutes=date.minute,
+                    hours=date.hour)
+                date_cur = date_end - datetime.timedelta(days=365)
+                date_step = datetime.timedelta(days=1)
+                bytes_recv = 1008000000
+                bytes_sent = 1008000000
+                bandwidth_rand = lambda x: random.randint(
+                    max(x - 100000000, 0), max(x + 100000000, 0))
+
+            data_p = {
+                'received': [],
+                'received_total': 0,
+                'sent': [],
+                'sent_total': 0,
+            }
+            data[period] = data_p
+
+            while date_cur < date_end:
+                date_cur += date_step
+
+                timestamp = int(date_cur.strftime('%s'))
+                bytes_recv = bandwidth_rand(bytes_recv)
+                bytes_sent = bandwidth_rand(bytes_sent)
+
+                data_p['received'].append((timestamp, bytes_recv))
+                data_p['received_total'] += bytes_recv
+                data_p['sent'].append((timestamp, bytes_sent))
+                data_p['sent_total'] += bytes_sent
+
+        if len(periods) == 1:
+            path = os.path.join(app_server.data_path,
+                'demo_bandwidth_%s' % periods[0])
+            with open(path, 'w') as demo_file:
+                demo_file.write(json.dumps(data[periods[0]]))
+            return data[periods[0]]
+        else:
+            path = os.path.join(app_server.data_path, 'demo_bandwidth')
+            with open(path, 'w') as demo_file:
+                demo_file.write(json.dumps(data))
+            return data
+
+    def _update_clients_bandwidth(self, clients):
+        # Remove client no longer connected
+        for client_id in cache_db.dict_keys(self.get_cache_key('clients')):
+            if client_id not in clients:
+                cache_db.dict_remove(self.get_cache_key('clients'), client_id)
+
+        # Get total bytes send and recv for all clients
+        bytes_recv_t = 0
+        bytes_sent_t = 0
+        for client_id in clients:
+            bytes_recv = clients[client_id]['bytes_received']
+            bytes_sent = clients[client_id]['bytes_sent']
+            prev_bytes_recv = 0
+            prev_bytes_sent = 0
+            client_prev = cache_db.dict_get(self.get_cache_key('clients'),
+                client_id)
+            cache_db.dict_set(self.get_cache_key('clients'), client_id,
+                '%s,%s' % (bytes_recv, bytes_sent))
+
+            if client_prev:
+                client_prev = client_prev.split(',')
+                prev_bytes_recv = int(client_prev[0])
+                prev_bytes_sent = int(client_prev[1])
+
+            if prev_bytes_recv > bytes_recv or prev_bytes_sent > bytes_sent:
+                prev_bytes_recv = 0
+                prev_bytes_sent = 0
+
+            bytes_recv_t += bytes_recv - prev_bytes_recv
+            bytes_sent_t += bytes_sent - prev_bytes_sent
+
+        # Store bytes send recv into time periods
+        if bytes_recv_t != 0 or bytes_sent_t != 0:
+            date = datetime.datetime.utcnow()
+            date -= datetime.timedelta(microseconds=date.microsecond,
+                seconds=date.second)
+
+            timestamp_1m = date.strftime('%s')
+            timestamp_1m_min = int((date - datetime.timedelta(
+                hours=6)).strftime('%s'))
+            date_5m = date - datetime.timedelta(minutes=date.minute % 5)
+            timestamp_5m = date_5m.strftime('%s')
+            timestamp_5m_min = int((date_5m - datetime.timedelta(
+                days=1)).strftime('%s'))
+            date_30m = date - datetime.timedelta(minutes=date.minute % 30)
+            timestamp_30m = date_30m.strftime('%s')
+            timestamp_30m_min = int((date_30m - datetime.timedelta(
+                days=7)).strftime('%s'))
+            date_2h = date - datetime.timedelta(
+                hours=date.hour % 2, minutes=date.minute)
+            timestamp_2h = date_2h.strftime('%s')
+            timestamp_2h_min = int((date_2h - datetime.timedelta(
+                days=30)).strftime('%s'))
+            date_1d = date - datetime.timedelta(
+                hours=date.hour, minutes=date.minute)
+            timestamp_1d = date_1d.strftime('%s')
+            timestamp_1d_min = int((date_1d - datetime.timedelta(
+                days=365)).strftime('%s'))
+
+            for period, timestamp, timestamp_min in (
+                        ('1m', timestamp_1m, timestamp_1m_min),
+                        ('5m', timestamp_5m, timestamp_5m_min),
+                        ('30m', timestamp_30m, timestamp_30m_min),
+                        ('2h', timestamp_2h, timestamp_2h_min),
+                        ('1d', timestamp_1d, timestamp_1d_min),
+                    ):
+                bytes_recv = bytes_recv_t
+                bytes_sent = bytes_sent_t
+                prev_bandwidth = persist_db.dict_get(
+                    self.get_cache_key('bandwidth-%s' % period), timestamp)
+                if prev_bandwidth:
+                    prev_bandwidth = prev_bandwidth.split(',')
+                    bytes_recv += int(prev_bandwidth[0])
+                    bytes_sent += int(prev_bandwidth[1])
+                persist_db.dict_set(self.get_cache_key(
+                    'bandwidth-%s' % period), timestamp,
+                    '%s,%s' % (bytes_recv, bytes_sent))
+
+                for timestamp_p in persist_db.dict_keys(self.get_cache_key(
+                        'bandwidth-%s' % period)):
+                    if int(timestamp_p) <= timestamp_min:
+                        persist_db.dict_remove(self.get_cache_key(
+                            'bandwidth-%s' % period), timestamp_p)
+
+            Event(type=SERVER_BANDWIDTH_UPDATED, resource_id=self.id)
+
+    def _read_clients(self):
+        clients = {}
         if os.path.isfile(self.ovpn_status_path):
             with open(self.ovpn_status_path, 'r') as status_file:
                 for line in status_file.readlines():
@@ -792,32 +1027,80 @@ class Server(Config):
                     client_id = line_split[1]
                     real_address = line_split[2]
                     virt_address = line_split[3]
-                    bytes_received = line_split[4]
+                    bytes_recv = line_split[4]
                     bytes_sent = line_split[5]
                     connected_since = line_split[7]
                     clients[client_id] = {
                         'real_address': real_address,
                         'virt_address': virt_address,
-                        'bytes_received': bytes_received,
-                        'bytes_sent': bytes_sent,
-                        'connected_since': connected_since,
+                        'bytes_received': int(bytes_recv),
+                        'bytes_sent': int(bytes_sent),
+                        'connected_since': int(connected_since),
                     }
+        self.update_clients(clients)
 
-        client_count = len(clients)
-        if client_count != self._cur_client_count:
-            self._cur_client_count = client_count
+    def update_clients(self, clients):
+        if not self.status:
+            return
+        self._update_clients_bandwidth(clients)
+        client_count = len(self.clients)
+        self.clients = clients
+        if client_count != len(clients):
             for org in self.iter_orgs():
                 Event(type=USERS_UPDATED, resource_id=org.id)
             Event(type=SERVERS_UPDATED)
 
-        self.clients = clients
-        return clients
+    @classmethod
+    def sort_servers_cache(cls):
+        servers_dict = {}
+        servers_sort = []
 
-    @staticmethod
-    def get_server(id):
+        # Create temp uuid key to prevent multiple threads modifying same key
+        temp_sorted_key = 'servers_sorted_temp_' + uuid.uuid4().hex
+
+        try:
+            for server_id_type in cache_db.set_elements('servers'):
+                server_id, server_type = server_id_type.split('_', 1)
+                server = Server.get_server(id=server_id, type=server_type)
+                if not server:
+                    continue
+                name_id = '%s_%s' % (server.name, server_id)
+                servers_dict[name_id] = server_id_type
+                servers_sort.append(name_id)
+            for name_id in sorted(servers_sort):
+                cache_db.list_rpush(temp_sorted_key, servers_dict[name_id])
+            cache_db.rename(temp_sorted_key, 'servers_sorted')
+        except:
+            cache_db.remove(temp_sorted_key)
+            raise
+
+    @classmethod
+    def _cache_servers(cls):
+        if cache_db.get('servers_cached') != 't':
+            cache_db.remove('servers')
+            path = os.path.join(app_server.data_path, SERVERS_DIR)
+            if os.path.isdir(path):
+                for server_id in os.listdir(path):
+                    if os.path.isfile(os.path.join(path, server_id,
+                            NODE_SERVER)):
+                        server_id += '_' + NODE_SERVER
+                    else:
+                        server_id += '_' + SERVER
+                    cache_db.set_add('servers', server_id)
+            cls.sort_servers_cache()
+            cache_db.set('servers_cached', 't')
+
+    @classmethod
+    def get_server(cls, id, type=None):
         from node_server import NodeServer
-        if os.path.isfile(os.path.join(app_server.data_path, SERVERS_DIR,
-                id, NODE_SERVER_NAME)):
+
+        if not type:
+            if cache_db.set_exists('servers', id + '_' + NODE_SERVER):
+                type = NODE_SERVER
+            else:
+                type = SERVER
+
+        if type == NODE_SERVER:
             server = NodeServer(id=id)
         else:
             server = Server(id=id)
@@ -830,14 +1113,11 @@ class Server(Config):
             return
         return server
 
-    @staticmethod
-    def iter_servers():
-        logger.debug('Getting servers.')
-        path = os.path.join(app_server.data_path, SERVERS_DIR)
-        servers = []
-        if os.path.isdir(path):
-            for server_id in os.listdir(path):
-                server = Server.get_server(id=server_id)
-                if server:
-                    servers.append(server)
-        return servers
+    @classmethod
+    def iter_servers(cls):
+        cls._cache_servers()
+        for server_id_type in cache_db.list_iter('servers_sorted'):
+            server_id, server_type = server_id_type.split('_', 1)
+            server = cls.get_server(id=server_id, type=server_type)
+            if server:
+                yield server
