@@ -18,8 +18,6 @@ cd pritunl-$VERSION
 debuild -S
 sed -i -e 's/0ubuntu1/0ubuntu1~quantal/g' debian/changelog
 debuild -S
-sed -i -e 's/0ubuntu1~quantal/0ubuntu1~raring/g' debian/changelog
-debuild -S
 sed -i -e 's/0ubuntu1~raring/0ubuntu1~saucy/g' debian/changelog
 debuild -S
 
@@ -28,5 +26,4 @@ cd ..
 echo '\n\nRUN COMMANDS BELOW TO UPLOAD:'
 echo 'sudo dput ppa:pritunl/ppa/ubuntu/precise ../build/debian/pritunl_'$VERSION'-0ubuntu1_source.changes'
 echo 'sudo dput ppa:pritunl/ppa/ubuntu/quantal ../build/debian/pritunl_'$VERSION'-0ubuntu1~quantal_source.changes'
-echo 'sudo dput ppa:pritunl/ppa/ubuntu/raring ../build/debian/pritunl_'$VERSION'-0ubuntu1~raring_source.changes'
 echo 'sudo dput ppa:pritunl/ppa/ubuntu/saucy ../build/debian/pritunl_'$VERSION'-0ubuntu1~saucy_source.changes'
