@@ -365,6 +365,11 @@ define([
   };
   routes['DELETE=/server/<serverId>/output'] = serverOutputDelete;
 
+  var serverBandwidthGet = function(request, serverId, period) {
+    request.response(demoData.serverBandwidth[period]);
+  };
+  routes['GET=/server/<serverId>/bandwidth/<period>'] = serverBandwidthGet;
+
   var statusGet = function(request) {
     var orgId;
     var userId;
@@ -415,7 +420,8 @@ define([
 
     for (id in demoData.users[orgId]) {
       if (request.data.search &&
-          demoData.users[orgId][id].name.indexOf(request.data.search) !== 0) {
+          demoData.users[orgId][id].name.toLowerCase().indexOf(
+            request.data.search.toLowerCase()) !== 0) {
         continue;
       }
       users.push(_.extend({
