@@ -17,9 +17,11 @@ define([
       'interface': null,
       'port': null,
       'protocol': null,
+      'dh_param_bits': null,
       'local_networks': null,
+      'dns_servers': null,
       'public_address': null,
-      'node_ip': null,
+      'node_host': null,
       'node_port': null,
       'node_key': null,
       'otp_auth': null,
